@@ -326,6 +326,15 @@
 #  endif
 #endif
 
+#if !defined(IUTEST_HAS_CATCH_SEH_EXCEPTION_ASSERTION)
+//! 例外アサーションで SEH をキャッチ可能かどうか
+#  if IUTEST_HAS_LAMBDA_STATEMENTS && IUTEST_HAS_SEH
+#    define IUTEST_HAS_CATCH_SEH_EXCEPTION_ASSERTION  1
+#  else
+#    define IUTEST_HAS_CATCH_SEH_EXCEPTION_ASSERTION  0
+#  endif
+#endif
+
 #if !defined(IUTEST_HAS_GENRAND)
 #  define IUTEST_HAS_GENRAND        1   //!< テストごとの genrand 関数が使用可能かどうか
 #endif
@@ -660,6 +669,7 @@
 #define IUTEST_USE_RANDOM_ENGINE_TYPENAME   ::std::default_random_engine
 
 #define IUTEST_NO_GETENV    //!< getenv 関数がない場合は定義
+#define IUTEST_NO_SETENV    //!< setenv 関数がない場合は定義
 #define IUTEST_NO_PUTENV    //!< putenv 関数がない場合は定義
 #define IUTEST_NO_GETCWD    //!< getcwd 関数がない場合は定義
 
